@@ -29,7 +29,7 @@ list_authorized_investigators <- function(party_id = 12, vb = FALSE, rq = NULL)
   if (is.null(rq)) {
     if (vb) {
       message("NULL request object. Will generate default.")
-      message("\nNot logged in. Only public information will be returned.")  
+      message("Not logged in. Only public information will be returned.")  
     }
     rq <- databraryr::make_default_request()
   }
