@@ -11,6 +11,16 @@ test_that("download_session_assets_fr_df rejects bad input parameters",
                                                                           2)))
             expect_error(download_session_assets_fr_df(target_dir = TRUE))
             
+            expect_error(download_session_assets_fr_df(add_session_subdir = -1))
+            expect_error(download_session_assets_fr_df(add_session_subdir = 3))
+            expect_error(download_session_assets_fr_df(add_session_subdir = "a"))
+            expect_error(download_session_assets_fr_df(add_session_subdir = list(a = 1, b = 2)))
+
+            expect_error(download_session_assets_fr_df(overwrite = -1))
+            expect_error(download_session_assets_fr_df(overwrite = 3))
+            expect_error(download_session_assets_fr_df(overwrite = "a"))
+            expect_error(download_session_assets_fr_df(overwrite = list(a = 1, b = 2)))
+            
             expect_error(download_session_assets_fr_df(make_portable_fn = -1))
             expect_error(download_session_assets_fr_df(make_portable_fn = 3))
             expect_error(download_session_assets_fr_df(make_portable_fn = "a"))
