@@ -9,6 +9,10 @@ test_that("get_party_by_id rejects bad input parameters", {
   expect_error(get_party_by_id(party_id = -1))
   expect_error(get_party_by_id(party_id = c(2,3)))
   expect_error(get_party_by_id(party_id = TRUE))
+
+  expect_error(get_party_by_id(parents_children_access = "a"))
+  expect_error(get_party_by_id(parents_children_access = -1))
+  expect_error(get_party_by_id(parents_children_access = c(2,3)))
   
   expect_error(get_party_by_id(vb = "a"))
   expect_error(get_party_by_id(vb = -1))
